﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace Wpf.Print.Sample.Common {
    public static class PrinterPaperModel {
        /// <summary>
        /// 인쇄할 용지 타입
        /// </summary>
        public enum PaperType {
            P72x20, // 80x28
            P72x48, // 80x56
            P72x72, // 80x80
            P72x96, // 80x104
            P72x128 // 80x136
        }

        /// <summary>
        /// 실제 인쇄 영역 정보가 들어있습니다 (단위 : Inch)
        /// </summary>
        public static IDictionary<PaperType, Size> PrintableArea = new Dictionary<PaperType, Size> {
            { PaperType.P72x20, new Size(Calculator.MmToInch(72), Calculator.MmToInch(20)) },
            { PaperType.P72x48, new Size(Calculator.MmToInch(72), Calculator.MmToInch(48)) },
            { PaperType.P72x72, new Size(Calculator.MmToInch(72), Calculator.MmToInch(72)) },
            { PaperType.P72x96, new Size(Calculator.MmToInch(72), Calculator.MmToInch(96)) },
            { PaperType.P72x128, new Size(Calculator.MmToInch(72), Calculator.MmToInch(128)) }
        };

        /// <summary>
        /// 인쇄 영역 크기를 가져옵니다
        /// </summary>
        public static Size GetPrintAreaSize(Size printArea) {
            //var printArea = PrintableArea[paperType]; // 가져올 용지 타입의 크기를 가져옵니다

            // 가져온 Inch 정보를 Pixel 로 변환한다
            printArea.Width = Calculator.InchToPixel(printArea.Width);
            printArea.Height = Calculator.InchToPixel(printArea.Height);

            // 변환한 Pixel 을 반올림해서 크기를 적용한다
            printArea.Width = Math.Round(printArea.Width);
            printArea.Height = Math.Round(printArea.Height);
            
            return printArea;
        }
    }
}
